API docs for “spamfighter.interfaces.IMessage”

# Class s.i.IMessage(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Known subclasses: spamfighter.interfaces.ITaggedMessage

Сообщение - основная единица обработки для Спамоборца.

Сообщение обладает тремя основными свойствами:

- от кого;
- кому;
- текст;
- время отправки.

Структурно поля "от кого" и "кому" ничем не отличаются, они описывают адресанта и адресата сообщения, соответственно. Поле "кому" может отсутствовать (например, если это сообщение - девиз пользователя на своей странице). Поля "от кого" и "кому" состоят из атрибутов (`IAttribute`).

Method | get | Получить атрибут по имени.

def get(name): (source)
Получить атрибут по имени.

Parameters | name | имя атрибута (type: `str` )
Returns | атрибут (type: `IAttribute` )